==> haskell-megaparsec-7.0.4-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-megaparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: megaparsec
version: 7.0.4
id: megaparsec-7.0.4-1CpsR9z4yywE3fIGM7EYlI
key: megaparsec-7.0.4-1CpsR9z4yywE3fIGM7EYlI
license: BSD-2-Clause
maintainer: Mark Karpov <markkarpov92@gmail.com>
author: Megaparsec contributors,
        Paolo Martini <paolo@nemail.it>,
        Daan Leijen <daan@microsoft.com>
homepage: https://github.com/mrkkrp/megaparsec
synopsis: Monadic parser combinators
description:
    This is an industrial-strength monadic parser combinator library.
    Megaparsec is a feature-rich package that strikes a nice balance between
    speed, flexibility, and quality of parse errors.
category: Parsing
abi: c72bcd1ce523076c8750b61f6facc02c
exposed: True
exposed-modules:
    Text.Megaparsec Text.Megaparsec.Byte Text.Megaparsec.Byte.Lexer
    Text.Megaparsec.Char Text.Megaparsec.Char.Lexer
    Text.Megaparsec.Debug Text.Megaparsec.Error
    Text.Megaparsec.Error.Builder Text.Megaparsec.Internal
    Text.Megaparsec.Pos Text.Megaparsec.Stream
hidden-modules: Text.Megaparsec.Class Text.Megaparsec.Common
                Text.Megaparsec.Lexer Text.Megaparsec.State
import-dirs: /usr/lib/ghc-8.6.4/site-local/megaparsec-7.0.4
library-dirs: /usr/lib/ghc-8.6.4/site-local/megaparsec-7.0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/megaparsec-7.0.4
hs-libraries: HSmegaparsec-7.0.4-1CpsR9z4yywE3fIGM7EYlI
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu containers-0.6.0.1
    deepseq-1.4.4.0 mtl-2.2.2
    parser-combinators-1.0.2-IyNQpKDV9bJE8mJzaajfJ
    scientific-0.3.6.2-BVEhLkswVxa6jxFFJ9XwaR text-1.2.3.1
    transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-megaparsec/html/megaparsec.haddock
haddock-html: /usr/share/doc/haskell-megaparsec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-megaparsec-7.0.4-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-megaparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: megaparsec
version: 7.0.4
id: megaparsec-7.0.4-LtBOPHXtadb29GI7W5CNMI
key: megaparsec-7.0.4-LtBOPHXtadb29GI7W5CNMI
license: BSD-2-Clause
maintainer: Mark Karpov <markkarpov92@gmail.com>
author: Megaparsec contributors,
        Paolo Martini <paolo@nemail.it>,
        Daan Leijen <daan@microsoft.com>
homepage: https://github.com/mrkkrp/megaparsec
synopsis: Monadic parser combinators
description:
    This is an industrial-strength monadic parser combinator library.
    Megaparsec is a feature-rich package that strikes a nice balance between
    speed, flexibility, and quality of parse errors.
category: Parsing
abi: 1f9bfc2e2f2cf493271aea20b9e9c88e
exposed: True
exposed-modules:
    Text.Megaparsec Text.Megaparsec.Byte Text.Megaparsec.Byte.Lexer
    Text.Megaparsec.Char Text.Megaparsec.Char.Lexer
    Text.Megaparsec.Debug Text.Megaparsec.Error
    Text.Megaparsec.Error.Builder Text.Megaparsec.Internal
    Text.Megaparsec.Pos Text.Megaparsec.Stream
hidden-modules: Text.Megaparsec.Class Text.Megaparsec.Common
                Text.Megaparsec.Lexer Text.Megaparsec.State
import-dirs: /usr/lib/ghc-8.6.4/site-local/megaparsec-7.0.4
library-dirs: /usr/lib/ghc-8.6.4/site-local/megaparsec-7.0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/megaparsec-7.0.4
hs-libraries: HSmegaparsec-7.0.4-LtBOPHXtadb29GI7W5CNMI
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu containers-0.6.0.1
    deepseq-1.4.4.0 mtl-2.2.2
    parser-combinators-1.0.2-IyNQpKDV9bJE8mJzaajfJ
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b text-1.2.3.1
    transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-megaparsec/html/megaparsec.haddock
haddock-html: /usr/share/doc/haskell-megaparsec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
